@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "dopo\N{U+0142}dnja",
-    "w\N{U+00f3}tpo\N{U+0142}dnja",
+    "dop.",
+    "w\N{U+00f3}tp.",
   ],
   available_formats => {
     Bh => "h B",
@@ -13,8 +13,8 @@
     EHm => "E, 'zeg'. H:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E, d.",
-    Ehm => "E, h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E, h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d. MMM y G",
@@ -29,17 +29,17 @@
     MEd => "E, d.M.",
     MMM => "LLL",
     MMMEd => "E, d. MMM",
-    "MMMMW-count-few" => "'ty\N{U+017a}e\N{U+0144}' W MMMM",
-    "MMMMW-count-one" => "'ty\N{U+017a}e\N{U+0144}' W MMMM",
-    "MMMMW-count-other" => "'ty\N{U+017a}e\N{U+0144}' W MMMM",
-    "MMMMW-count-two" => "'ty\N{U+017a}e\N{U+0144}' W MMMM",
-    MMMMd => "d MMMM",
+    "MMMMW-count-few" => "W. 'ty\N{U+017a}e\N{U+0144}' MMMM",
+    "MMMMW-count-one" => "W. 'ty\N{U+017a}e\N{U+0144}' MMMM",
+    "MMMMW-count-other" => "W. 'ty\N{U+017a}e\N{U+0144}' MMMM",
+    "MMMMW-count-two" => "W. 'ty\N{U+017a}e\N{U+0144}' MMMM",
+    MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     Md => "d.M.",
-    d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    d => "d.",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
@@ -53,10 +53,10 @@
     yMd => "d.M.y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-few" => "'ty\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
-    "yw-count-one" => "'ty\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
-    "yw-count-other" => "'ty\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
-    "yw-count-two" => "'ty\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
+    "yw-count-few" => "w. 'ty\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
+    "yw-count-one" => "w. 'ty\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
+    "yw-count-other" => "w. 'ty\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
+    "yw-count-two" => "w. 'ty\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
   },
   code => "dsb-DE",
   date_format_full => "EEEE, d. MMMM y",
@@ -231,10 +231,10 @@
   native_territory => "Nimska",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "kw1",
+    "kw2",
+    "kw3",
+    "kw4",
   ],
   quarter_format_narrow => [
     1,
@@ -249,10 +249,10 @@
     "4. kwartal",
   ],
   quarter_stand_alone_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "kw1",
+    "kw2",
+    "kw3",
+    "kw4",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -273,5 +273,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 41,
+  version => 45,
 }
