@@ -73,7 +73,7 @@
   date_format_short => "d/M/yy",
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
-  datetime_format_medium => "{1} {0}",
+  datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "lun",
@@ -281,5 +281,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 42,
+  version => 45,
 }
