@@ -35,8 +35,8 @@
     Md => "d/M",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "m:ss",
@@ -219,8 +219,8 @@
     "kr\N{U+00ed}simin",
   ],
   name => "Kwasio",
-  native_language => "nmg",
-  native_name => "nmg",
+  native_language => undef,
+  native_name => "",
   native_script => undef,
   native_territory => undef,
   native_variant => undef,
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 45,
 }
